rename methods in System/Host to be more consistent.


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@62776 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/ExecutionEngine/ExecutionEngine.cpp b/lib/ExecutionEngine/ExecutionEngine.cpp
index a1fbdd2..d1a406c 100644
--- a/lib/ExecutionEngine/ExecutionEngine.cpp
+++ b/lib/ExecutionEngine/ExecutionEngine.cpp
@@ -692,7 +692,7 @@
   assert((IntVal.getBitWidth()+7)/8 >= StoreBytes && "Integer too small!");
   uint8_t *Src = (uint8_t *)IntVal.getRawData();
 
-  if (sys::littleEndianHost())
+  if (sys::isLittleEndianHost())
     // Little-endian host - the source is ordered from LSB to MSB.  Order the
     // destination from LSB to MSB: Do a straight copy.
     memcpy(Dst, Src, StoreBytes);
@@ -751,7 +751,7 @@
     cerr << "Cannot store value of type " << *Ty << "!\n";
   }
 
-  if (sys::littleEndianHost() != getTargetData()->isLittleEndian())
+  if (sys::isLittleEndianHost() != getTargetData()->isLittleEndian())
     // Host and target are different endian - reverse the stored bytes.
     std::reverse((uint8_t*)Ptr, StoreBytes + (uint8_t*)Ptr);
 }
@@ -762,7 +762,7 @@
   assert((IntVal.getBitWidth()+7)/8 >= LoadBytes && "Integer too small!");
   uint8_t *Dst = (uint8_t *)IntVal.getRawData();
 
-  if (sys::littleEndianHost())
+  if (sys::isLittleEndianHost())
     // Little-endian host - the destination must be ordered from LSB to MSB.
     // The source is ordered from LSB to MSB: Do a straight copy.
     memcpy(Dst, Src, LoadBytes);
@@ -789,7 +789,7 @@
                                           const Type *Ty) {
   const unsigned LoadBytes = getTargetData()->getTypeStoreSize(Ty);
 
-  if (sys::littleEndianHost() != getTargetData()->isLittleEndian()) {
+  if (sys::isLittleEndianHost() != getTargetData()->isLittleEndian()) {
     // Host and target are different endian - reverse copy the stored
     // bytes into a buffer, and load from that.
     uint8_t *Src = (uint8_t*)Ptr;
diff --git a/lib/System/Unix/Host.inc b/lib/System/Unix/Host.inc
index 7bee66f..205ce23 100644
--- a/lib/System/Unix/Host.inc
+++ b/lib/System/Unix/Host.inc
@@ -23,7 +23,7 @@
 
 using namespace llvm;
 
-std::string llvm::sys::osName() {
+std::string llvm::sys::getOSName() {
   struct utsname info;
 
   if (uname(&info))
@@ -32,7 +32,7 @@
   return info.sysname;
 }
 
-std::string llvm::sys::osVersion() {
+std::string llvm::sys::getOSVersion() {
   struct utsname info;
 
   if (uname(&info))
diff --git a/lib/System/Win32/Host.inc b/lib/System/Win32/Host.inc
index 7bbf2bd..4fabc78 100644
--- a/lib/System/Win32/Host.inc
+++ b/lib/System/Win32/Host.inc
@@ -17,11 +17,11 @@
 
 using namespace llvm;
 
-std::string sys::osName() {
+std::string sys::getOSName() {
   return "Windows";
 }
 
-std::string sys::osVersion() {
+std::string sys::getOSVersion() {
   OSVERSIONINFO osvi;
 
   memset(&osvi, 0, sizeof(osvi));
diff --git a/include/llvm/System/Host.h b/include/llvm/System/Host.h
index 7119593..22e36e7 100644
--- a/include/llvm/System/Host.h
+++ b/include/llvm/System/Host.h
@@ -19,7 +19,7 @@
 namespace llvm {
 namespace sys {
 
-  inline bool littleEndianHost() {
+  inline bool isLittleEndianHost() {
     union {
       int i;
       char c;
@@ -28,17 +28,17 @@
     return c;
   }
 
-  inline bool bigEndianHost() {
-    return !littleEndianHost();
+  inline bool isBigEndianHost() {
+    return !isLittleEndianHost();
   }
 
   /// osName() - Return the name of the host operating system or "" if
   /// unknown.
-  std::string osName();
+  std::string getOSName();
 
   /// osVersion() - Return the operating system version as a string or
   /// "" if unknown.
-  std::string osVersion();
+  std::string getOSVersion();
 }
 }
 
@@ -28,17 +28,17 @@
   }
 
-  /// osName() - Return the name of the host operating system or "" if
+  /// getOSName() - Return the name of the host operating system or "" if
   /// unknown.
@@ -28,17 +28,17 @@
 
-  /// osVersion() - Return the operating system version as a string or
+  /// getOSVersion() - Return the operating system version as a string or
   /// "" if unknown.